def FormatToDotCase(string: str) -> str:
    """Converts a string to dot.case.

    Args:
        string: str. The string to be converted.

    Returns:
        str. The converted string.
    """
    string = string.replace(" ", "_").replace("-", "_")
    return string.replace("_", ".").lower()



def ConvertBinaryToDecimal(binary: str) -> int:
    """Convert a binary number to a decimal number."""
    decimal = 0
    for digit in binary:
        decimal = decimal * 2 + int(digit)
    return decimal



import re


def FormatToSnakeCase(string: str) -> str:
    """Converts a string to snake case.

    Args:
        string: str. The string to be converted.

    Returns:
        str. The converted string.
    """
    string = string.replace(" ", "_").replace("-", "_")
    string = re.sub(r"(.)([A-Z][a-z]+)", r"\1_\2", string)
    return re.sub(r"([a-z0-9])([A-Z])", r"\1_\2", string).lower()



def FormatToPathCase(s: str) -> str:
    """Converts a string to path case.

    Args:
        s: string to be converted.

    Returns:
        s converted to path case.
    """
    s = s.replace(" ", "_").replace("-", "_")
    return s.replace("_", "/").lower()



def ConvertDecimalToBinary(decimal: int) -> str:
    """Convert a decimal number to a binary number."""
    binary = ""
    while decimal > 0:
        binary += str(decimal % 2)
        decimal //= 2
    return binary[::-1]



def ConvertDecimalToOctal(decimal: int) -> int:
    """Convert a decimal number to an octal number."""
    octal = 0
    i = 1
    while decimal != 0:
        octal += (decimal % 8) * i
        decimal //= 8
        i *= 10
    return octal



def ConvertHexadecimalToDecimal(hexadecimal: str) -> int:
    """Convert a hexadecimal number to a decimal number."""
    decimal = 0
    for i in range(len(hexadecimal)):
        decimal += int(hexadecimal[i], 16) * 16 ** (len(hexadecimal) - i - 1)
    return decimal



def FormatToConstantCase(s: str) -> str:
    """Converts a string to constant case.

    Args:
        s: The string to convert.

    Returns:
        The string in constant case.
    """
    s = s.replace(" ", "_").replace("-", "_")
    return "_".join([x.upper() for x in s.split("_")])



from .convert_binary_to_decimal import ConvertBinaryToDecimal


def ConvertBinaryToHexadecimal(binary: str) -> str:
    """Convert a binary number to a hexadecimal number."""
    decimal = ConvertBinaryToDecimal(binary)
    hexadecimal = ""
    while decimal > 0:
        hexadecimal = str(decimal % 16) + hexadecimal
        decimal = decimal // 16
    return hexadecimal



def FormatToCamelCase(s: str) -> str:
    """Converts a string to camel case.

    Args:
      s: The string to convert.

    Returns:
      The string in camel case.
    """
    s = s.replace(" ", "_").replace("-", "_")
    words = s.split("_")
    camel_case = words[0].lower()
    for word in words[1:]:
        camel_case += word.capitalize()
    return camel_case



def ConvertBinaryToOctal(binary: str) -> int:
    """Convert a binary number to an octal number."""
    octal = 0
    for i, digit in enumerate(binary[::-1]):
        octal += int(digit) * 2**i
    return octal


print(ConvertBinaryToOctal("1001"))



def FormatToTitleCase(text: str) -> str:
    """Converts a string to title case, with some exceptions.

    Args:
        text: str. The string to be converted.

    Returns:
        str. The converted string.
    """
    text = text.replace(" ", "_").replace("-", "_")
    return text.replace("_", " ").title()



def FormatToPascalCase(text: str) -> str:
    """Converts a string to PascalCase.

    Args:
        text: The string to convert.

    Returns:
        The PascalCase version of the string.
    """
    text = text.replace(" ", "_").replace("-", "_")
    words = text.split("_")
    pascal_case = words[0].capitalize()
    for word in words[1:]:
        pascal_case += word.capitalize()
    return pascal_case



from .convert_octal_to_decimal import ConvertOctalToDecimal
from .convert_decimal_to_hexadecimal import ConvertDecimalToHexadecimal


def ConvertOctalToHexadecimal(octal: int) -> int:
    """Convert an octal number to a hexadecimal number."""
    if octal == 0:
        return 0
    return int(ConvertDecimalToHexadecimal(ConvertOctalToDecimal(str(octal))))



def ConvertOctalToDecimal(octal: str) -> int:
    """Convert an octal number to a decimal number."""
    decimal = 0
    for i in range(len(octal)):
        decimal = decimal * 8 + int(octal[i])
    return decimal
